//#define XERR
#include "survival.ih"

void Survival::refresh()
{
    for (auto &vsd: d_vsd)
        vsd.refresh();
}
